summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authormattm@chromium.org <mattm@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2010-06-16 03:02:38 +0000
committermattm@chromium.org <mattm@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2010-06-16 03:02:38 +0000
commit0738a30690b8992c412ac968816e1ea8479577d8 (patch)
tree40035e0b34db110d2f5f39c970713162d3e29ebb
parent39e8c48020b4b985e9314838ca1270410e328b61 (diff)
downloadchromium_src-0738a30690b8992c412ac968816e1ea8479577d8.zip
chromium_src-0738a30690b8992c412ac968816e1ea8479577d8.tar.gz
chromium_src-0738a30690b8992c412ac968816e1ea8479577d8.tar.bz2
gtk: prefix CertificateManagerPage enum names to avoid namespace polution.
BUG=none TEST=builds Review URL: http://codereview.chromium.org/2812004 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@49892 0039d316-1c4b-4281-b951-d872f2087c98
-rw-r--r--chrome/browser/gtk/certificate_manager.cc10
-rw-r--r--chrome/browser/gtk/certificate_manager.h19
2 files changed, 15 insertions, 14 deletions
diff --git a/chrome/browser/gtk/certificate_manager.cc b/chrome/browser/gtk/certificate_manager.cc
index 06a616e..4c52f8e 100644
--- a/chrome/browser/gtk/certificate_manager.cc
+++ b/chrome/browser/gtk/certificate_manager.cc
@@ -471,7 +471,7 @@ void CertificateManager::OnSwitchPage(GtkWidget* notebook,
GtkNotebookPage* page,
guint page_num) {
int index = static_cast<int>(page_num);
- DCHECK(index > PAGE_DEFAULT && index < PAGE_COUNT);
+ DCHECK(index > CERT_MANAGER_PAGE_DEFAULT && index < CERT_MANAGER_PAGE_COUNT);
last_selected_page_.SetValue(index);
}
@@ -481,15 +481,15 @@ void CertificateManager::ShowCertificatePage(CertificateManagerPage page) {
gtk_window_present_with_time(GTK_WINDOW(dialog_),
gtk_get_current_event_time());
- if (page == PAGE_DEFAULT) {
+ if (page == CERT_MANAGER_PAGE_DEFAULT) {
// Remember the last visited page from local state.
page = static_cast<CertificateManagerPage>(last_selected_page_.GetValue());
- if (page == PAGE_DEFAULT)
- page = PAGE_USER;
+ if (page == CERT_MANAGER_PAGE_DEFAULT)
+ page = CERT_MANAGER_PAGE_USER;
}
// If the page number is out of bounds, reset to the first tab.
if (page < 0 || page >= gtk_notebook_get_n_pages(GTK_NOTEBOOK(notebook_)))
- page = PAGE_USER;
+ page = CERT_MANAGER_PAGE_USER;
gtk_notebook_set_current_page(GTK_NOTEBOOK(notebook_), page);
}
diff --git a/chrome/browser/gtk/certificate_manager.h b/chrome/browser/gtk/certificate_manager.h
index f8534bc..5587bcd 100644
--- a/chrome/browser/gtk/certificate_manager.h
+++ b/chrome/browser/gtk/certificate_manager.h
@@ -12,16 +12,17 @@ class PrefService;
// An identifier for the Certificate Manager window. These are treated as
// indices into the list of available tabs to be displayed.
// PAGE_DEFAULT means select the last tab viewed when the Certificate Manager
// window was opened, or PAGE_USER if the Certificate Manager was never opened.
enum CertificateManagerPage {
- PAGE_DEFAULT = -1,
- PAGE_USER,
- PAGE_EMAIL,
- PAGE_SERVER,
- PAGE_CA,
- PAGE_UNKNOWN,
- PAGE_COUNT
+ CERT_MANAGER_PAGE_DEFAULT = -1,
+ CERT_MANAGER_PAGE_USER,
+ CERT_MANAGER_PAGE_EMAIL,
+ CERT_MANAGER_PAGE_SERVER,
+ CERT_MANAGER_PAGE_CA,
+ CERT_MANAGER_PAGE_UNKNOWN,
+ CERT_MANAGER_PAGE_COUNT
};
namespace certificate_manager_util {
@@ -12,16 +12,17 @@ class PrefService;
// An identifier for the Certificate Manager window. These are treated as
// indices into the list of available tabs to be displayed.
-// PAGE_DEFAULT means select the last tab viewed when the Certificate Manager
-// window was opened, or PAGE_USER if the Certificate Manager was never opened.
+// CERT_MANAGER_PAGE_DEFAULT means select the last tab viewed when the
+// Certificate Manager window was opened, or CERT_MANAGER_PAGE_USER if the
+// Certificate Manager was never opened.
enum CertificateManagerPage {